@@ -59,6 +59,7 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.4",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.5",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.6",
+    "Environment :: GPU :: NVIDIA CUDA :: 13",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -240,6 +241,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Wagtail :: 4",
     "Framework :: Wagtail :: 5",
     "Framework :: Wagtail :: 6",
+    "Framework :: Wagtail :: 7",
     "Framework :: ZODB",
     "Framework :: Zope",
     "Framework :: Zope2",
@@ -352,6 +354,7 @@ sorted_classifiers: List[str] = [
     "License :: Repoze Public License",
     "Natural Language :: Afrikaans",
     "Natural Language :: Arabic",
+    "Natural Language :: Armenian",
     "Natural Language :: Basque",
     "Natural Language :: Bengali",
     "Natural Language :: Bosnian",
@@ -367,6 +370,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Dutch",
     "Natural Language :: English",
     "Natural Language :: Esperanto",
+    "Natural Language :: Estonian",
     "Natural Language :: Finnish",
     "Natural Language :: French",
     "Natural Language :: Galician",
@@ -411,6 +415,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Ukrainian",
     "Natural Language :: Urdu",
     "Natural Language :: Vietnamese",
+    "Natural Language :: Yiddish",
     "Operating System :: Android",
     "Operating System :: BeOS",
     "Operating System :: MacOS",
@@ -525,8 +530,15 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Python :: 3.12",
     "Programming Language :: Python :: 3.13",
     "Programming Language :: Python :: 3.14",
+    "Programming Language :: Python :: 3.15",
+    "Programming Language :: Python :: Free Threading",
+    "Programming Language :: Python :: Free Threading :: 1 - Unstable",
+    "Programming Language :: Python :: Free Threading :: 2 - Beta",
+    "Programming Language :: Python :: Free Threading :: 3 - Stable",
+    "Programming Language :: Python :: Free Threading :: 4 - Resilient",
     "Programming Language :: Python :: Implementation",
     "Programming Language :: Python :: Implementation :: CPython",
+    "Programming Language :: Python :: Implementation :: GraalPy",
     "Programming Language :: Python :: Implementation :: IronPython",
     "Programming Language :: Python :: Implementation :: Jython",
     "Programming Language :: Python :: Implementation :: MicroPython",
